Learn R Programming

cqrReg (version 1.2.1)

CQRCDCPP: Composite Quantile Regression (cqr) use Coordinate Descent (cd) Algorithms core computational part

Description

Composite quantile regression (cqr) find the estimated coefficient which minimize the absolute error for various quantile level. The algorithm base on greedy coordinate descent and Edgeworth's for ordinary \(l_1\) regression.

Arguments