Learn R Programming

cqrReg (version 1.2.1)

QR.lasso.ip: Quantile Regression (QR) with Adaptive Lasso Penalty (lasso) use Interior Point (ip) Method

Description

The function use the interior point method from quantreg to solve the quantile regression problem.

Usage

QR.lasso.ip(X,y,tau,lambda)

Arguments

X

the design matrix

y

response variable

tau

quantile level

lambda

The constant coefficient of penalty function. (default lambda=1)

Value

a list structure is with components

beta

the vector of estimated coefficient

b

intercept

lambda

The constant coefficient of penalty function. (default lambda=1)

References

Koenker, R. and S. Portnoy (1997). The Gaussian Hare and the Laplacian Tortoise: Computability of squared-error vs. absolute-error estimators, with discussion, Statistical Science, 12, 279-300.

Wu, Yichao and Liu, Yufeng (2009). Variable selection in quantile regression. Statistica Sinica, 19, 801--817.

Examples

Run this code
# NOT RUN {
set.seed(1)
n=100
p=2
a=2*rnorm(n*2*p, mean = 1, sd =1)
x=matrix(a,n,2*p)
beta=2*rnorm(p,1,1)
beta=rbind(matrix(beta,p,1),matrix(0,p,1))
y=x%*%beta-matrix(rnorm(n,0.1,1),n,1)
# x is 1000*20 matrix, y is 1000*1 vector, beta is 20*1 vector with last ten zero value elements. 
#you should install Rmosek first to run following command
#QR.lasso.ip(x,y,0.1)
# }

Run the code above in your browser using DataLab