Learn R Programming

cqrReg (version 1.2.1)

cqr.admm: Composite Quantile regression (cqr) use Alternating Direction Method of Multipliers (ADMM) algorithm.

Description

Composite quantile regression (cqr) find the estimated coefficient which minimize the absolute error for various quantile level. The problem is well suited to distributed convex optimization and is based on Alternating Direction Method of Multipliers (ADMM) algorithm .

Usage

cqr.admm(X,y,tau,rho,beta, maxit, toler)

Arguments

X

the design matrix

y

response variable

tau

vector of quantile level

rho

augmented Lagrangian parameter

beta

initial value of estimate coefficient (default naive guess by least square estimation)

maxit

maxim iteration (default 200)

toler

the tolerance critical for stop the algorithm (default 1e-3)

Value

a list structure is with components

beta

the vector of estimated coefficient

b

intercept

References

S. Boyd, N. Parikh, E. Chu, B. Peleato and J. Eckstein.(2010) Distributed Optimization and Statistical Learning via the Alternating Direction. Method of Multipliers Foundations and Trends in Machine Learning, 3, No. 1, 1--122

Hui Zou and Ming Yuan(2008). Composite Quantile Regression and the Oracle Model Selection Theory, The Annals of Statistics, 36, Number 3, Page 1108--1126.

Examples

Run this code
# NOT RUN {
set.seed(1)
n=100
p=2
a=rnorm(n*p, mean = 1, sd =1)
x=matrix(a,n,p)
beta=rnorm(p,1,1)
beta=matrix(beta,p,1)
y=x%*%beta-matrix(rnorm(n,0.1,1),n,1)
tau=1:5/6
# x is 1000*10 matrix, y is 1000*1 vector, beta is 10*1 vector
cqr.admm(x,y,tau)
# }

Run the code above in your browser using DataLab